pub struct XYZ { /* private fields */ }Expand description
Structure representing Cartesian (EPSG:4979) coordinates
直交座標系(EPSG:4979)座標を表す構造体
Implementations
Sourceimpl XYZ
impl XYZ
Sourcepub fn new(x: f64, y: f64, z: f64) -> Self
pub fn new(x: f64, y: f64, z: f64) -> Self
Create a new Cartesian (EPSG:4979) coordinate
直交座標系(EPSG:4979)座標を新しく作成する
Sourcepub fn to_ll(&self) -> LL
pub fn to_ll(&self) -> LL
Convert to a structure representing latitude and longitude
緯度経度を表す構造体に変換する
Sourcepub fn to_ll_with_altitude(&self) -> (LL, f64)
pub fn to_ll_with_altitude(&self) -> (LL, f64)
Convert to a structure representing latitude and longitude with altitude (m)
緯度経度を表す構造体と標高(m)に変換する
Sourcepub fn to_jpr(&self, origin: JprOrigin) -> JPR
pub fn to_jpr(&self, origin: JprOrigin) -> JPR
Convert to a structure representing JPR coordinates
平面直角座標を表す構造体に変換する
Sourcepub fn to_jpr_with_altitude(&self, origin: JprOrigin) -> (JPR, f64)
pub fn to_jpr_with_altitude(&self, origin: JprOrigin) -> (JPR, f64)
Convert to a structure representing JPR coordinates with altitude (m)
平面直角座標を表す構造体と標高(m)に変換する
Sourcepub fn to_pixel(&self, zoom_lv: ZoomLv) -> Pixel
pub fn to_pixel(&self, zoom_lv: ZoomLv) -> Pixel
Convert to a structure representing pixel coordinates ピクセル座標を表す構造体に変換する
Sourcepub fn to_pixel_with_altitude(&self, zoom_lv: ZoomLv) -> (Pixel, f64)
pub fn to_pixel_with_altitude(&self, zoom_lv: ZoomLv) -> (Pixel, f64)
Convert to a structure representing pixel coordinates with altitude (m)
ピクセル座標を表す構造体と標高(m)に変換する